/*
 * MailServlet.java
 */

package com.runstate.mailpage;

import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintWriter;
import javax.servlet.*;
import javax.servlet.http.*;

public class MailServlet extends HttpServlet {
    
    private MailRetriever mailretriever;
    
    public void init(ServletConfig config) throws ServletException {
        super.init(config);
        String emailuser=config.getInitParameter("emailuser");
        String emailpassword=config.getInitParameter("emailpassword");
        String emailserver=config.getInitParameter("emailserver");
        String emailprovider=config.getInitParameter("emailprovider");
        
        mailretriever=new MailRetriever(emailuser,emailpassword,emailserver,emailprovider);
    }
    
    public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        if(request.getPathInfo().equals("/")) {
            response.setContentType("text/html;charset=UTF-8");
            PrintWriter out = response.getWriter();
            mailretriever.getMail();
            Renderable msg=mailretriever.getLatestMessage();
            
            if(msg==null) {
                out.println("<html><head><title>Error</title></head><body>Error: No valid mail in mailbox</body></html>");
                out.close();
                return;
            }
            
            out.println("<html><head><title>"+msg.getSubject()+"</title></head>");
            out.println("<body><h1>"+msg.getSubject()+"</h1>");
            
            String bodytext=msg.getBodytext();
            
            // This is added to correct cid references
           for(int i=0;i<msg.getAttachmentCount();i++) {
                Attachment attachment=msg.getAttachment(i);
                String cidraw=attachment.getContentid();
                if(cidraw!=null) {
                    String cid=null;
                    String url=attachment.getFilename();
                    
                    if(cidraw.startsWith("<")&&cidraw.endsWith(">")) {
                        cid="cid:"+cidraw.substring(1,cidraw.length()-1);
                    } else {
                        cid="cid:"+cidraw;
                    }
                    
                    bodytext=bodytext.replaceAll(cid,url);
                }
            } 
            
            out.println(bodytext);
            
            out.println("<HR/>");
            
            out.println("Attachments :<UL>");
            for(int i=0;i<msg.getAttachmentCount();i++) {
                Attachment attachment=msg.getAttachment(i);
                out.println("<LI><A href=\""+attachment.getFilename()+"\">"+attachment.getFilename()+"</A>");
            }
            
            out.println("</body>");
            out.println("</html>");
            out.close();
            return;
        } else {
            Renderable msg=mailretriever.getLatestMessage();
           
            if(msg!=null && request.getPathInfo().startsWith("/")) {
                String image=request.getPathInfo().substring(1);
                for(int i=0;i<msg.getAttachmentCount();i++) {
                    Attachment attachment=msg.getAttachment(i);
                    if(attachment.getFilename().equals(image)) {
                        response.setContentType(attachment.getContenttype());
                        OutputStream os=response.getOutputStream();
                        os.write(attachment.getContent());
                        os.close();
                        return;
                    }
                }
            }
        }
        response.sendError(response.SC_NOT_FOUND);
   }
    
    
    
}
